#[non_exhaustive]pub enum ApiError {
Unauthorized,
RateLimit {
retry_after: Option<u64>,
},
NotFound,
ServerError {
status: u16,
},
NetworkError(Error),
ParseError(String),
}Expand description
All errors that can be returned by the WakaTime API client.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The API key is invalid or was not provided. Maps to HTTP 401.
RateLimit
The API rate limit has been exceeded. Maps to HTTP 429.
retry_after contains the number of seconds to wait before retrying,
if the server included a Retry-After header.
NotFound
The requested resource was not found. Maps to HTTP 404.
ServerError
An unexpected server-side error occurred. Maps to HTTP 5xx.
NetworkError(Error)
A network-level error occurred (connection refused, timeout, DNS, etc.).
ParseError(String)
The server returned a response that could not be deserialized.