#[non_exhaustive]pub struct DailyAverage {
pub holidays: u32,
pub days_including_holidays: u32,
pub days_minus_holidays: u32,
pub seconds: f64,
pub text: String,
pub seconds_including_other_language: f64,
pub text_including_other_language: String,
}Expand description
Daily average returned as part of SummaryResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.holidays: u32Number of days in the range with no coding activity logged.
days_including_holidays: u32Total number of days in the range.
days_minus_holidays: u32Number of days in the range excluding days with no activity.
seconds: f64Average seconds per day, excluding the “Other” language.
text: StringHuman-readable daily average, excluding the “Other” language.
seconds_including_other_language: f64Average seconds per day, including all languages.
text_including_other_language: StringHuman-readable daily average, including all languages.