#[non_exhaustive]pub struct LeaderboardEntry {
pub rank: Option<u32>,
pub running_total: RunningTotal,
pub user: LeaderboardUser,
}Expand description
A single entry on the leaderboard.
Used for both regular entries in data and the current_user object.
rank is None when the authenticated user is not on the current page.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rank: Option<u32>The rank of this user (1 = top coder).
None when the current_user is not present on this page.
running_total: RunningTotalAggregated coding totals for this user.
user: LeaderboardUserPublic user information.