Stats

Struct Stats 

#[non_exhaustive]
pub struct Stats {
Show 46 fields pub best_day: Option<BestDay>, pub categories: Vec<SummaryEntry>, pub created_at: String, pub daily_average: f64, pub daily_average_including_other_language: f64, pub days_including_holidays: u32, pub days_minus_holidays: u32, pub dependencies: Vec<SummaryEntry>, pub editors: Vec<SummaryEntry>, pub end: String, pub holidays: u32, pub human_readable_daily_average: String, pub human_readable_daily_average_including_other_language: String, pub human_readable_range: String, pub human_readable_total: String, pub human_readable_total_including_other_language: String, pub ai_additions: u32, pub ai_deletions: u32, pub human_additions: u32, pub human_deletions: u32, pub id: Option<String>, pub is_already_updating: bool, pub is_coding_activity_visible: bool, pub is_language_usage_visible: bool, pub is_editor_usage_visible: bool, pub is_category_usage_visible: bool, pub is_os_usage_visible: bool, pub is_stuck: bool, pub is_including_today: bool, pub is_up_to_date: bool, pub languages: Vec<SummaryEntry>, pub machines: Vec<MachineEntry>, pub modified_at: Option<String>, pub operating_systems: Vec<SummaryEntry>, pub percent_calculated: u32, pub projects: Vec<SummaryEntry>, pub range: String, pub start: String, pub status: String, pub timeout: u32, pub timezone: String, pub total_seconds: f64, pub total_seconds_including_other_language: f64, pub user_id: String, pub username: String, pub writes_only: bool,
}
Aggregated coding stats for a predefined time range.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
best_day: Option<BestDay>

The day with the most coding activity.

categories: Vec<SummaryEntry>

Time broken down by activity category.

created_at: String

ISO 8601 timestamp when this stats snapshot was created.

daily_average: f64

Average daily coding time in seconds, excluding “Other” language.

daily_average_including_other_language: f64

Average daily coding time in seconds, including all languages.

days_including_holidays: u32

Number of days in the range including weekends/holidays.

days_minus_holidays: u32

Number of working days in the range (excluding days with no activity).

dependencies: Vec<SummaryEntry>

Time broken down by detected dependency / library.

editors: Vec<SummaryEntry>

Time broken down by editor.

end: String

ISO 8601 end of the stats range.

holidays: u32

Number of holiday / zero-activity days in the range.

human_readable_daily_average: String

Human-readable average daily coding time, excluding “Other” language.

human_readable_daily_average_including_other_language: String

Human-readable average daily coding time, including all languages.

human_readable_range: String

Human-readable description of the range (e.g. "last 7 days").

human_readable_total: String

Human-readable total coding time, excluding “Other” language.

human_readable_total_including_other_language: String

Human-readable total coding time, including all languages.

ai_additions: u32

Lines added by AI coding assistants (e.g. GitHub Copilot).

ai_deletions: u32

Lines removed by AI coding assistants.

human_additions: u32

Lines added by the developer via keyboard input.

human_deletions: u32

Lines removed by the developer via keyboard input.

id: Option<String>

Unique stats record identifier (not always present in the API response).

is_already_updating: bool

Whether the stats snapshot is currently refreshing in the background.

is_coding_activity_visible: bool

Whether this user’s coding activity is publicly visible.

is_language_usage_visible: bool

Whether this user’s language usage is publicly visible.

is_editor_usage_visible: bool

Whether this user’s editor usage is publicly visible.

is_category_usage_visible: bool

Whether this user’s category usage is publicly visible.

is_os_usage_visible: bool

Whether this user’s operating system usage is publicly visible.

is_stuck: bool

Whether the stats calculation got stuck and will be retried.

is_including_today: bool

Whether these stats include the current (partial) day.

is_up_to_date: bool

Whether the stats snapshot is up to date.

languages: Vec<SummaryEntry>

Time broken down by programming language.

machines: Vec<MachineEntry>

Time broken down by machine.

modified_at: Option<String>

ISO 8601 timestamp when this snapshot was last modified.

operating_systems: Vec<SummaryEntry>

Time broken down by operating system.

percent_calculated: u32

How fully computed the stats are (0–100).

projects: Vec<SummaryEntry>

Time broken down by project.

range: String

Named range (e.g. "last_7_days", "last_30_days").

start: String

ISO 8601 start of the stats range.

status: String

Computation status (e.g. "ok", "pending_update").

timeout: u32

Heartbeat timeout in minutes used for this calculation.

timezone: String

IANA timezone used when computing the stats.

total_seconds: f64

Total coding time in seconds, excluding “Other” language.

total_seconds_including_other_language: f64

Total coding time in seconds, including all languages.

user_id: String

Owner user identifier (UUID).

username: String

Owner username.

writes_only: bool

Whether the account is in write-only mode.